<?php
	class Curl {
		private $handle;

		function __construct($headers = []) {
			$this->handle=curl_init();
			$this->setDefaults();
			if ($headers)
				$this->setHeaders($headers);
		}

		function set($param, $value) {
			curl_setopt($this->handle, $param, $value);
		}

		function setDefaults() {
			$this->setTimeout(20);
			$this->set(CURLOPT_RETURNTRANSFER, 1);
			$this->set(CURLOPT_FOLLOWLOCATION, 1);
			$this->set(CURLOPT_HEADER, 0);
		}

		function setTimeout($seconds) {
			$this->set(CURLOPT_TIMEOUT, $seconds);
		}
		
		function setHeaders($headers=[]) {
			$assoc = [];
			foreach($headers as $name => $val)
				$assoc[] = $name.': '.$val;
			$this->set(CURLOPT_HTTPHEADER, $assoc);
		}

		function cookies($cookies) {
			if (!is_array($cookies)) {
				$this->set(CURLOPT_COOKIE, $cookies);
			} else {
				$arr=array();
				foreach($cookies as $key => $val)
					$arr[]=$key.':'.$val;
				$this->set(CURLOPT_COOKIE, implode(';', $arr));
			}
		}

		function useProxy($proxy, $user=false, $pass=false) {
			$this->set(CURLOPT_PROXY, $proxy);
			$this->set(CURLOPT_HTTPPROXYTUNNEL, 1);
			if ($user and $pass)
				$this->set(CURLOPT_PROXYUSERPWD, $user.':'.$pass);
		}

		function send() {
			$ret=curl_exec($this->handle);
			if ($error=curl_error($this->handle))
				echo $error;
			return $ret;
		}

		function get($url, $data=[]) {
			$this->set(CURLOPT_POST, 0);
			if ($data)
				$url.='?'.http_build_query($data);
			$this->set(CURLOPT_URL, $url);
			return $this->send();
		}
		
		private function req($method, $url, $data=[]) {
			if ($method == 'POST') {
				$this->set(CURLOPT_POST, 1);
			} else {
				$this->set(CURLOPT_CUSTOMREQUEST, $method);
			}
			$this->set(CURLOPT_POSTFIELDS, is_array($data) ? http_build_query($data) : $data);
			$this->set(CURLOPT_URL, $url);
			return $this->send();			
		}

		function post($url, $data=[]) {
			return $this->req('POST', $url, $data);
		}
		
		function put($url, $data=[]) {
			return $this->req('PUT', $url, $data);
		}

		function __destruct() {
			curl_close($this->handle);
		}
	}
?>
