<?php
require_once('curl.php');

class Keystone {
	
	function __construct() {
		$this->headers = [
			'X-Auth-Token' => Config::secret,
			'Content-Type' => 'application/json'
		];
	}
	
	private function isError($response) {
		if ( !empty($response['error']) ) {
			echo $response['error']['message'];
			// exception, something went wrong
			return true;
		}		
	}
	
	function changePass($id, $pass) {
		$url = Config::adminUrl . 'users/' . urlencode($id) . '/OS-KSADM/password';

		$data = [ 'user' => [
			'id' => $id,
			'password' => $pass,
		] ];
		
		$c = new Curl($this->headers);
		$response = json_decode($c->put($url, json_encode($data)), true);
	}
	
	// get user by name
	function user($name) {
		$url = Config::adminUrl . 'users/?name=' . urlencode($name);
		
		$c = new Curl($this->headers);
		$response = json_decode($c->get($url), true);
		
		if ( empty( $response['user'] ) )
			return false;
		return $response['user'];		
	}
	
	// get tenant by name
	function tenant($name) {
		$url = Config::adminUrl . 'tenants/?name=' . urlencode($name);
		
		$c = new Curl($this->headers);
		$response = json_decode($c->get($url), true);
		
		if ( empty( $response['tenant'] ) )
			return false;
		return $response['tenant'];			
	}
	
	// this function adds the user to keystone, returns user
	function register($name, $email, $pass, $tenant, $enabled = true) {
		$url = Config::adminUrl . 'users';
		
		$data = [ 'user' => [
			'name' => $name,
			'email' => $email,
			'password' => $pass,
			'tenantId' => $this->tenant($tenant)['id'],
			'enabled' => $enabled,
		] ];
		
		$c = new Curl($this->headers);
		$response = json_decode( $c->post($url, json_encode($data)), true );
		if ($this->isError($response))
			return false;
		
		if ( !empty($response['user']) )
			return $response['user'];
		return false;
	}
	
	// this function authenticates user, returns token
	// NOT USED / NEEDED currently
	function auth($name, $pass) {
		$url = Config::userUrl . 'tokens';
		
		$headers = [
			'Content-Type' => 'application/json'
		];
		
		$data = [ 'auth' => [
			'passwordCredentials' => [
				'username' => $name,
				'password' => $pass,
			],
			//'tenantName' => 'admin'
		] ];

		$c = new Curl($headers);
		$response = json_decode( $c->post($url, json_encode($data)), true );
		if ($this->isError($response))
			return false;
		
		if ( !empty($response['access']['token']) )
			return $response['access']['token'];
		return false;
	}
}
